package de.skyrix.modules.actions.portlets;
import java.io.IOException;
import java.net.MalformedURLException;
import java.text.DateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Collection;
import java.util.Locale;

import org.apache.jetspeed.modules.actions.portlets.JspPortletAction;
import org.apache.jetspeed.portal.Portlet;
import org.apache.jetspeed.util.PortletSessionState;
import org.apache.turbine.util.Log;
import org.apache.turbine.util.RunData;

import skyrix.JobManager;
/**
 * @author buhle 
 *
 * Liest alle Jobs aus und gibt die erhaltene Collection von Jobs an 
 * showJobs.jsp weiter.
 */
public class ShowJobs extends JspPortletAction
{
	/**
	 * Standardmethode, die automatisch vor Aufruf der JSP-Seite abgearbeitet wird
	 * bei Portlets
	 * 
	 * @see org.apache.jetspeed.modules.actions.portlets.JspPortletAction#buildNormalContext(Portlet, RunData)
	 */
	protected void buildNormalContext(Portlet portlet, RunData rundata)
	{
    JobManager jm = null;
    PortletProperties pp = new PortletProperties();

		try
		{
			int fault = 0;
      int iLines = 10;
      int actLines = 0;
      
      if ((String)PortletSessionState.getAttributeWithFallback(portlet, rundata, "act_lines") != null)
        actLines = Integer.parseInt((String)PortletSessionState.getAttributeWithFallback(portlet, rundata, "act_lines"));
      
      // Wieviel Zeilen angezeigt werden sollen wird ausgelesen
      String strLines = (String)PortletSessionState.getAttributeWithFallback(portlet, rundata, "lines");
      if (strLines != null && strLines.length() > 0)
        iLines = Integer.parseInt((String) PortletSessionState.getAttributeWithFallback(portlet, rundata, "lines"));
      // Wenn der Wert 0 oder niedriger ist, wird er auf 10 gesetzt.
      if (iLines <1) iLines = 10;
      
      // Das Startdatum wird ausgelesen
			String strBegin = (String) PortletSessionState.getAttributeWithFallback(portlet, rundata, "startdate");
			// Das Enddatum wird ausgelesen
			String strEnd = (String) PortletSessionState.getAttributeWithFallback(portlet, rundata,	"enddate");
			// Verbindung aufbauen 
  		try
      {
        Client client = new Client(pp.getHost(), rundata.getUser().getUserName(), rundata.getUser().getPassword());
        jm = new JobManager(client.getClient());
      }
      catch (MalformedURLException ex)
      {
        Log.debug(ex.toString());
        fault = 1;
      }
      catch (IOException ex)
      {
        Log.debug(ex.toString());
        fault = 2;
      }
      
			Locale loc = new Locale("de", "DE");
			DateFormat df = DateFormat.getDateInstance(DateFormat.SHORT, loc);
			// Beide Datumsangaben werden versucht in ein Datum zu parsen 
			java.util.Date begin = new java.util.Date();
			java.util.Date end = new java.util.Date();
			
      try
			{
				java.util.Date newBegin = df.parse(strBegin);
				if (newBegin.getTime() > begin.getTime())
					begin = newBegin;
			}
			catch (Exception e){}
			
      try
			{
				java.util.Date newEnd = df.parse(strEnd);
				if (newEnd.getTime() > end.getTime())
					end = newEnd;
			}
			catch (Exception e){}
      
			// Wenn das Enddatum kleiner ist als das Startdatum werden beide gleichgesetzt
      if (end.getTime() <= begin.getTime())
      {
        Calendar cal = Calendar.getInstance();
        cal.setTime(begin);
        cal.add(Calendar.DAY_OF_YEAR, 1);
        end = cal.getTime();
      }  
//			Log.debug("jobs: " + begin + " - " + end);
      
			// Alle Jobs werden geholt.
			Collection collection = jm.getAllJobs(begin, end);
      ArrayList jobList = null;
      
      // Bildet aus der Collection eine ArrayList die nur die aktuell angezeigten Jobs enthlt
      boolean next = true;
      boolean prior = true;
      int endLines = 0;
      if (collection != null)  
			{
        jobList = new ArrayList(collection);
        // Nur wenn die anzuzeigenden Zeilen nicht grsser sind als die existierenden Jobs
        if (jobList.size() > iLines)
        {
          ArrayList dummy = new ArrayList();
          if (actLines+iLines < jobList.size())
          {
            endLines = actLines+iLines;
            if (actLines == 0) prior = false;
          }
          else 
          {
            endLines = jobList.size();
            next = false;
          }
          // Die ArrayList wird erstellt.
          for (int i=actLines;i<endLines;i++)
          {
            dummy.add(jobList.get(i));
          }
          jobList = dummy;
        }
        // Es gibt keine vorherigen oder weiteren Jobs die angezeigt werden mssten.
        else 
        {
          next = false;
          prior = false;
        } 
			}
      
      // Es werden die bentigten Daten der JSP-Seite als Attribute in ihr hinterlegt. 
			rundata.getRequest().setAttribute("jobs", jobList);
      rundata.getRequest().setAttribute("fault", new Integer(fault));
      rundata.getRequest().setAttribute("skyrix_link", pp.getSkyrixLink());
      rundata.getRequest().setAttribute("act_lines", new Integer(endLines));
      rundata.getRequest().setAttribute("lines", new Integer(iLines));
      rundata.getRequest().setAttribute("hasNext", new Boolean(next));
      rundata.getRequest().setAttribute("hasPrior", new Boolean(prior));
		}
		catch (Exception e)
		{
			Log.error(e);
		}
	}
}
